@@ -1,4 +1,4 @@
-/* xml++.h
+/* textreader.h
  * libxml++ and this file are copyright (C) 2000 by Ari Johnson, and
  * are covered by the GNU Lesser General Public License, which should be
  * included with libxml++ as the file COPYING.
@@ -12,6 +12,8 @@
 
 #include <glibmm/ustring.h>
 
+#include <memory>
+
 extern "C"
 {
   struct _xmlTextReader;
@@ -81,10 +83,10 @@ class TextReader: NonCopyable
     /**
      * Creates a new TextReader object which parses in memory data. 
      * @param data The data to parse.
-     * @param size The length of data, or -1 if null terminated.
+     * @param size The number of bytes in data.
      * @param uri The base URI of the file.
      */ 
-    TextReader(const char* data, size_type size, const Glib::ustring& uri = Glib::ustring());
+    TextReader(const unsigned char* data, size_type size, const Glib::ustring& uri = Glib::ustring());
     		   
     ~TextReader();
     
